/********************************************************************************
*                                                                               *
*       ADSP-21161 Initialization of Sport 1 and 3   	                        *
*																				*
*		M.Adas - European DSP Applications - July 2003							*
*																				*	
*********************************************************************************/
	
/* ADSP-21161 System Register bit definitions */

#include 	"def21161.h"

//.global Init_sport_regs;
//.global Setup_DMA_Channels_Sport13;
.global rx1a_buf;
.global tx3a_buf;
.global init_dags;
.extern Init_sport_regs;
.extern Setup_DMA_Channels_Sport13;
.extern init_dags;


#define PCI 0x40000
#define N 1024

.section /dm dm_data;
.var rx1a_buf[1024];
.var tx3a_buf[1024];

.section /dm    dm_codec;

/* TCB = "Transfer Control Block" */
/* TCB format:    ECx (length of destination buffer),
				  EMx (destination buffer step size),
				  EIx (destination buffer index (initialized to start address)),
				  GPx ("general purpose"),
				  CPx ("Chain Point register"; points to last address (IIx) of
			   								   next TCB to jump to
				                               upon completion of this TCB.),
				  Cx  (length of source buffer),
				  IMx (source buffer step size),
				  IIx (source buffer index (initialized to start address))       */
				  
.var 	sp1a_tcb[5] = 0, sp1a_tcb+4, N, 1, rx1a_buf;  /* SPORT1 receive channel a tcb */
.var 	sp3a_tcb[5] = 0, sp3a_tcb+4, N, 1, tx3a_buf;  /* SPORT3 transmit channel a tcb */
				  
.section /pm 	pm_code;

	
/****************************************************************************
*		Sport 1 channel A and Sport 3 channel A DMA setup 					*  
****************************************************************************/

Setup_DMA_Channels_Sport13:
 
/* PCI assignments  */

	/* SPORT1 dma control rx setup channel A */
	ustat1 = dm(sp1a_tcb + 1);		/* get DMA chaining internal mem pointer containing rx_buf address */
	bit set ustat1 PCI;				/* set the pci bit */	
	dm(sp1a_tcb + 1) = ustat1;    	/* write DMA receive block chain pointer to TCB buffer*/
				                 	/* receive block chain pointer, initiate rx1 DMA transfers */

	/* SPORT3 dma control tx setup channel A  */
	ustat1 = dm(sp3a_tcb + 1);		/* get DMA chaining internal mem pointer containing tx_buf address */
	bit set ustat1 PCI;				/* set the pci bit */
	dm(sp3a_tcb + 1) = ustat1; 		/* write DMA transmit block chain pointer to TCB buffer */
				                 	/* transmit block chain pointer, initiate tx3 DMA transfers */
			                 	/* transmit block chain pointer, initiate tx3 DMA transfers */
Setup_DMA_Channels_Sport13.end:
rts;

/****************************************************************************
*		Init of the DAGs (transmit and receive buffer)						*  
****************************************************************************/

init_dags:

b0=rx1a_buf;				// address of the receive buffer
l0=length(rx1a_buf);		// length of the receive buffer 
m0=1;						// modifier 

b1=tx3a_buf;				// address of the transmit buffer a
l1=length(tx3a_buf);		
m1=1;

init_dags.end:
rts;



/****************************************************************************
*		Sport 1 and Sport 3 Control Register Setup							*  
****************************************************************************/

Init_sport_regs:

	R0 = 0x00000000;	// frame sync and clock from the codec
	dm(DIV1) = R0;		
	dm(DIV3) = R0;
	dm(SPCTL1)=R0;
	dm(SPCTL3)=R0;
	
	// SPORT 1 control register set up as a receiver in normal serial mode
	R0 = SCHEN_A | SDEN_A | SLEN16 | SPEN_A | FSR; 
	dm(SPCTL1) = R0;			
	
/*			 	SCHEN_A		DMA Chaining Enable A channel
				SDEN_A		SPORT DMA enable A channel
				SLEN16		Serial Word Length - 1 
				SPEN_A		SPORT Enable A
*/

	// SPORT 3 control register set up as a transmitter in normal serial mode
	R0 = SCHEN_A | SDEN_A | SLEN16 | SPEN_A | DDIR | FSR; 
	dm(SPCTL3) = R0;			
	
/*			 	SCHEN_A		DMA Chaining Enable A channel
				SDEN_A		SPORT DMA enable A channel
				SLEN16		Serial Word Length - 1 
				SPEN_A		SPORT Enable A
				DDIR		Data Direction Control: Enable Active Transmit Buffers TX3A/TX3B
*/
	

/* Kick off DMA chaining of SPORT1&3 */

r8=sp1a_tcb+4; 
r9=sp3a_tcb+4;

dm(CP1A)=r8;			// SPORT1 channel A DMA chain enable
dm(CP3A)=r9;			// SPORT3 channel A DMA chain enable

Init_sport_regs.end:
rts;



