/********************************************************************************
*                                                                               *
*       AD74111 Register Initialization with the Sport 3   						*
*																				*
*		M.Adas - European DSP Applications - July 2003							*
*																				*	
*********************************************************************************/

/* ADSP-21161 System Register bit definitions */
#include 	"def21161.h"

.extern Program_AD74111;

// 	AD74111 codec register commands
//
//	Bit  15		:	Read or Write (0=read, 1=write)
//	Bits 14:11	:	Codec Register Address
//	Bit  10 	:	reserved bit, always 0
//	Bits 9:0 	:	Data Field 
//
// AD74111  register definitions
//#define		Read_Reg		0x0000	// bit 15 not set
//#define		Write_Reg		0x8000	// bit 15 set

//#define		DAC_ControlA 	0x0000	// address of reg A:0000
//#define		DAC_ControlB	0x0800	// address of reg B:0001 
//#define		DAC_ControlC	0x1000	// address of reg C:0010
//#define		DAC_ControlD	0x1800	// address of reg D:0011
//#define		DAC_ControlE	0x2000	// address of reg E:0100 
//#define		DAC_ControlF	0x2800	// address of reg F:0101
//#define		DAC_ControlG	0x3000	// address of reg G:0110

.section/dm dm_data;
 

.var control_reg[12] = //program register commands
0x807c,	// DAC reg A: ADC, DAC, ADC input & Reference amplifier on,
0x5555, // dummy word
0x8800,	// DAC reg B: divide by 1
0x5555, // dummy word
0x9000, // DAC reg C: 16 bits, no de-emphasis, high pass filter disabled
0x5555, // dummy word
0xA000, // DAC reg E: peak disabled,  gain 0 dB, ADC/DAC mute normal
0x5555, // dummy word
0xB000, // DAC reg G: DAC volume 0 dBFS
0x5555, // dummy word
0x9801, // DAC reg D: normal mode, data mode, 16 bit, master, 128 * fs
0x5555; // dummy word

// write control register D as last register to set it in data mode
// otherwise, no possibility to configure the codec 
					

//.var rx_buf3[7];

.section /pm pm_code;

/////////////////////////////////////////////////////////////////////////////////////////
//	                                                                                   //
//           Program SPORT1 & SPORT3 Control Registers                                 //	
//                                                                                     //
/////////////////////////////////////////////////////////////////////////////////////////

Program_AD74111:

		
Sport3_dma_setup:

		// clear multichannel/miscellaneous control register for SPORT1 & SPORT3 
		R0 = 0x0; 			
		dm(SP13MCTL) = R0;
		dm(DIV3) = R0;
		dm(DIV1) = R0;
		nop;
		
		IRPTL = 0x00000000;			// clear pending interrupts 
//		bit set mode1 IRPTEN;   	// enable global interrupts
		nop;		 
		bit set imask SP3I;			// enable SPORT3 interrupts
		nop;
		
		
		// wait for the reset process of the codec AD74111 3072 MCLK periods
		lcntr = 0x7fff, do wait_for_codec until lce;  // 	 
		wait_for_codec:
				nop;
				nop;
		
				
		// setup parameter register for dma transfer of the control data via sport 3 
		r0=control_reg;				dm(II3A)=r0;    // Internal DMA6 memory address		      			   
 		r0=1;						dm(IM3A)=r0;	// Internal DMA6 memory access modifier	      	   	 
		r0=length(control_reg);		dm(C3A)=r0;	 	// Contains number of DMA6 transfers to be done 

		ustat1 = 0x00000000;			// clear sport register 3 
		dm(SPCTL3) = ustat1;
		bit set ustat1 DDIR | SLEN16 | SPEN_A | FSR | SDEN_A; 
		dm(SPCTL3) = ustat1;
			
		/* SPCTL3 SPORT CONTROL REGISTER BITs
		DDIR 	= Transmitter, if set
		SLEN16	= word length - 1		
		SPEN_A 	= Sport Enable channel A
		*/

	

nop;
nop;
 	


lcntr = 0xffff, do (pc,2) until lce;  
 	 
nop;
nop;
nop;	

Program_AD74111.end: rts;



